@@ -31,6 +31,10 @@ class Job;
 class Slave;
 }
 
+namespace KGAPI2 {
+class AccountPromise;
+}
+
 class SmtpJobPrivate;
 
 namespace MailTransport {
@@ -69,6 +73,8 @@ protected Q_SLOTS:
     void sessionStateChanged(KSmtp::Session::State state);
 
 private:
+    void startPasswordRetrieval(bool forceRefresh = false);
+    void onTokenRequestFinished(KGAPI2::AccountPromise *result);
     void startSmtpJob();
     void startLoginJob();
     void startSendJob();
