@@ -32,9 +32,9 @@ public:
     });
     ~SMTPMailTransportPlugin() override;
 
-    QVector<MailTransport::TransportAbstractPluginInfo> names() const override;
-    bool configureTransport(const QString &identifier, MailTransport::Transport *transport, QWidget *parent) override;
-    MailTransport::TransportJob *createTransportJob(MailTransport::Transport *t, const QString &identifier) override;
+    Q_REQUIRED_RESULT QVector<MailTransport::TransportAbstractPluginInfo> names() const override;
+    Q_REQUIRED_RESULT bool configureTransport(const QString &identifier, MailTransport::Transport *transport, QWidget *parent) override;
+    Q_REQUIRED_RESULT MailTransport::TransportJob *createTransportJob(MailTransport::Transport *t, const QString &identifier) override;
 };
 
 #endif // SMTPMAILTRANSPORTPLUGIN_H
